# pywrdgen
Generate (possibly) secure passwords.

Just a little project to toy around with. I don't intend this to be anything
ground-breaking and exciting. Just a little utility to generate password(s).

# use
From inside your virtual environment of choice, install the requirements. Then
run the module or source file directly. This might be done as..

```bash
pip install -r requirements.txt    # Install requirements
python -m pywrdgen                 # Run as a module
python pywrdgen/__main__.py        # Run the source file directly

python -m pywrdgen --help          # Display global flags help
python -m pywrdgen gen --help      # Display generator flags help
```

# contributing
Any, and all contributions are welcome. Be it issues, suggestions, thanks. I
appreciate all of it. Feel free to submit a pull request, or write an issue 
with what's on your mind.
